@@ -12,12 +12,12 @@ import (
 
 // A GPGEncryption uses gpg for encryption and decryption. See https://gnupg.org/.
 type GPGEncryption struct {
-	Command    string
-	Args       []string
-	Recipient  string
-	Recipients []string
-	Symmetric  bool
-	Suffix     string
+	Command    string   `json:"command" mapstructure:"command" yaml:"command"`
+	Args       []string `json:"args" mapstructure:"args" yaml:"args"`
+	Recipient  string   `json:"recipient" mapstructure:"recipient" yaml:"recipient"`
+	Recipients []string `json:"recipients" mapstructure:"recipients" yaml:"recipients"`
+	Symmetric  bool     `json:"symmetric" mapstructure:"symmetric" yaml:"symmetric"`
+	Suffix     string   `json:"suffix" mapstructure:"suffix" yaml:"suffix"`
 }
 
 // Decrypt implements Encryption.Decrypt.
