@@ -111,6 +111,7 @@ type SourceState struct {
 	readTemplateData        bool
 	userTemplateData        map[string]any
 	priorityTemplateData    map[string]any
+	scriptEnv               []string
 	templateData            map[string]any
 	templateFuncs           template.FuncMap
 	templateOptions         []string
@@ -199,6 +200,13 @@ func WithReadTemplateData(readTemplateData bool) SourceStateOption {
 	}
 }
 
+// WithScriptEnv sets the script environment variables.
+func WithScriptEnv(scriptEnv []string) SourceStateOption {
+	return func(s *SourceState) {
+		s.scriptEnv = scriptEnv
+	}
+}
+
 // WithSourceDir sets the source directory.
 func WithSourceDir(sourceDirAbsPath AbsPath) SourceStateOption {
 	return func(s *SourceState) {
@@ -1038,6 +1046,9 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 	// Generate SourceStateCommands for git-repo externals.
 	var gitRepoExternalRelPaths RelPaths
 	for externalRelPath, external := range s.externals {
+		if s.Ignore(externalRelPath) {
+			continue
+		}
 		if external.Type == ExternalTypeGitRepo {
 			gitRepoExternalRelPaths = append(gitRepoExternalRelPaths, externalRelPath)
 		}
@@ -1673,6 +1684,7 @@ func (s *SourceState) newModifyTargetStateEntryFunc(
 
 			// Run the modifier on the current contents.
 			cmd := interpreter.ExecCommand(tempFile.Name())
+			cmd.Env = s.scriptEnv
 			cmd.Stdin = bytes.NewReader(currentContents)
 			cmd.Stderr = os.Stderr
 			contents, err = chezmoilog.LogCmdOutput(cmd)
