@@ -53,6 +53,10 @@ func (c *Config) newAddCmd() *cobra.Command {
 	flags.BoolVarP(&c.Add.template, "template", "T", c.Add.template, "Add files as templates")
 	flags.BoolVar(&c.Add.TemplateSymlinks, "template-symlinks", c.Add.TemplateSymlinks, "Add symlinks with target in source or home dirs as templates") //nolint:lll
 
+	if err := flags.MarkDeprecated("autotemplate", "it will be removed in a future release"); err != nil {
+		panic(err)
+	}
+
 	registerExcludeIncludeFlagCompletionFuncs(addCmd)
 
 	return addCmd
